==> haskell-gi-gtk-hs-0.3.17-60-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-2UwjRBWzpWhD7kqAKrc8aZ
key:                  gi-gtk-hs-0.3.17-2UwjRBWzpWhD7kqAKrc8aZ
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  712f524fbb2be5535db77b18906020e4
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-2UwjRBWzpWhD7kqAKrc8aZ
depends:
    base-4.17.2.1 base-compat-0.13.1-8jgXJjtFto7AX0ry1QXDcA
    containers-0.6.7 gi-gdk-3.0.28-20CTxyqSFhPJyM84p9Oe6J
    gi-gdkpixbuf-2.0.32-EUDK34K7u9j9bil9QChWGi
    gi-glib-2.0.30-8IsCgAFsNyvCMo3Uv1tktt
    gi-gobject-2.0.31-CO9g5YrfupcL82TBm9IlSW
    gi-gtk-3.0.41-KJliUXI9MvgJ3nWzCrzI1D
    haskell-gi-base-0.26.6-8Q7bG4vZp6hk1q5uA8ktg mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-gi-gtk-hs-0.3.17-87-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-gi-gtk-hs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 gi-gtk-hs
version:              0.3.17
visibility:           public
id:                   gi-gtk-hs-0.3.17-8lvQdRfg8ftIInZCL0hO5E
key:                  gi-gtk-hs-0.3.17-8lvQdRfg8ftIInZCL0hO5E
license:              LGPL-2.1-only
maintainer:           mail@jonasplatte.de
author:
    Jonas Platte,
    Duncan Coutts,
    Axel Simon,
    Hamish Mackenzie,
    Iñaki García Etxebarria

homepage:             https://github.com/haskell-gi/haskell-gi
synopsis:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

description:
    A wrapper for gi-gtk, adding a few more idiomatic API parts on top

category:             Graphics
abi:                  d8214804f5c562fbace7e6f54f33e407
exposed:              True
exposed-modules:
    Data.GI.Gtk Data.GI.Gtk.BuildFn Data.GI.Gtk.ComboBox
    Data.GI.Gtk.ModelView.CellLayout Data.GI.Gtk.ModelView.CustomStore
    Data.GI.Gtk.ModelView.ForestStore Data.GI.Gtk.ModelView.SeqStore
    Data.GI.Gtk.ModelView.TreeModel Data.GI.Gtk.ModelView.Types
    Data.GI.Gtk.Threading Data.GI.Gtk.Widget

import-dirs:          /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs:         /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/gi-gtk-hs-0.3.17
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-gi-gtk-hs
hs-libraries:         HSgi-gtk-hs-0.3.17-8lvQdRfg8ftIInZCL0hO5E
depends:
    base-4.17.2.1 base-compat-0.14.1-EDnSvJBeGTDBBfh2KFPKKz
    containers-0.6.7 gi-gdk-3.0.29-7L47FAcvyJtLJfKBVoMiZg
    gi-gdkpixbuf-2.0.32-2KIBWLy4rvcI0yJMvbU69z
    gi-glib-2.0.30-ByVChIeQE982wAN9upa7TB
    gi-gobject-2.0.31-6EB5iuj4Cem7mzVZlVtaZP
    gi-gtk-3.0.42-IMxk7w3W0bSKcbzBtjZGc6
    haskell-gi-base-0.26.9-JwtixDByddv9QLYzDFao9J mtl-2.2.2 text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/haskell-gi-gtk-hs/html/gi-gtk-hs.haddock
haddock-html:         /usr/share/doc/haskell-gi-gtk-hs/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
